@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 github3.events
 ==============
@@ -5,11 +6,13 @@ github3.events
 This module contains the class(es) related to Events
 
 """
+from __future__ import unicode_literals
 
-from github3.models import GitHubObject
+from .models import GitHubObject
 
 
 class Event(GitHubObject):
+
     """The :class:`Event <Event>` object. It structures and handles the data
     returned by via the `Events <http://developer.github.com/v3/events>`_
     section of the GitHub API.
@@ -25,10 +28,11 @@ class Event(GitHubObject):
         e1.id != e2.id
 
     """
+
     def __init__(self, event):
         super(Event, self).__init__(event)
-        from github3.users import User
-        from github3.orgs import Organization
+        from .users import User
+        from .orgs import Organization
         #: :class:`User <github3.users.User>` object representing the actor.
         self.actor = User(event.get('actor')) if event.get('actor') else None
         #: datetime object representing when the event was created.
@@ -41,7 +45,7 @@ class Event(GitHubObject):
             self.org = Organization(event.get('org'))
         #: Event type http://developer.github.com/v3/activity/events/types/
         self.type = event.get('type')
-        handler = _payload_handlers[self.type]
+        handler = _payload_handlers.get(self.type, identity)
         #: Dictionary with the payload. Payload structure is defined by type_.
         #  _type: http://developer.github.com/v3/events/types
         self.payload = handler(event.get('payload'))
@@ -52,15 +56,9 @@ class Event(GitHubObject):
         #: Indicates whether the Event is public or not.
         self.public = event.get('public')
 
-    def __repr__(self):
+    def _repr(self):
         return '<Event [{0}]>'.format(self.type[:-5])
 
-    def __eq__(self, other):
-        return self.id == other.id
-
-    def __ne__(self, other):
-        return self.id != other.id
-
     @staticmethod
     def list_types():
         """List available payload types"""
@@ -77,43 +75,36 @@ class Event(GitHubObject):
 
 
 def _commitcomment(payload):
-    from github3.repos.comment import RepoComment
+    from .repos.comment import RepoComment
     if payload.get('comment'):
         payload['comment'] = RepoComment(payload['comment'], None)
     return payload
 
 
-def _download(payload):
-    from github3.repos.download import Download
-    if payload.get('download'):
-        payload['download'] = Download(payload['download'], None)
-    return payload
-
-
 def _follow(payload):
-    from github3.users import User
+    from .users import User
     if payload.get('target'):
         payload['target'] = User(payload['target'], None)
     return payload
 
 
 def _forkev(payload):
-    from github3.repos import Repository
+    from .repos import Repository
     if payload.get('forkee'):
         payload['forkee'] = Repository(payload['forkee'], None)
     return payload
 
 
 def _gist(payload):
-    from github3.gists import Gist
+    from .gists import Gist
     if payload.get('gist'):
         payload['gist'] = Gist(payload['gist'], None)
     return payload
 
 
 def _issuecomm(payload):
-    from github3.issues import Issue
-    from github3.issues.comment import IssueComment
+    from .issues import Issue
+    from .issues.comment import IssueComment
     if payload.get('issue'):
         payload['issue'] = Issue(payload['issue'], None)
     if payload.get('comment'):
@@ -122,63 +113,76 @@ def _issuecomm(payload):
 
 
 def _issueevent(payload):
-    from github3.issues import Issue
+    from .issues import Issue
     if payload.get('issue'):
         payload['issue'] = Issue(payload['issue'], None)
     return payload
 
 
 def _member(payload):
-    from github3.users import User
+    from .users import User
     if payload.get('member'):
         payload['member'] = User(payload['member'], None)
     return payload
 
 
 def _pullreqev(payload):
-    from github3.pulls import PullRequest
+    from .pulls import PullRequest
     if payload.get('pull_request'):
         payload['pull_request'] = PullRequest(payload['pull_request'], None)
     return payload
 
 
 def _pullreqcomm(payload):
-    from github3.pulls import ReviewComment
+    from .pulls import ReviewComment
     if payload.get('comment'):
         payload['comment'] = ReviewComment(payload['comment'], None)
     return payload
 
 
+def _release(payload):
+    from .repos.release import Release
+    release = payload.get('release')
+    if release:
+        payload['release'] = Release(release)
+    return payload
+
+
 def _team(payload):
-    from github3.orgs import Team
-    from github3.repos import Repository
-    from github3.users import User
+    from .orgs import Team
+    from .repos import Repository
+    from .users import User
     if payload.get('team'):
         payload['team'] = Team(payload['team'], None)
     if payload.get('repo'):
         payload['repo'] = Repository(payload['repo'], None)
-    if payload.get('user'):
-        payload['user'] = User(payload['user'], None)
+    if payload.get('sender'):
+        payload['sender'] = User(payload['sender'], None)
     return payload
 
 
+def identity(x):
+    return x
+
+
 _payload_handlers = {
     'CommitCommentEvent': _commitcomment,
-    'CreateEvent': lambda x: x,
-    'DeleteEvent': lambda x: x,
-    'DownloadEvent': _download,
+    'CreateEvent': identity,
+    'DeleteEvent': identity,
     'FollowEvent': _follow,
     'ForkEvent': _forkev,
-    'ForkApplyEvent': lambda x: x,
+    'ForkApplyEvent': identity,
     'GistEvent': _gist,
-    'GollumEvent': lambda x: x,
+    'GollumEvent': identity,
     'IssueCommentEvent': _issuecomm,
     'IssuesEvent': _issueevent,
     'MemberEvent': _member,
     'PublicEvent': lambda x: '',
     'PullRequestEvent': _pullreqev,
     'PullRequestReviewCommentEvent': _pullreqcomm,
-    'PushEvent': lambda x: x,
+    'PushEvent': identity,
+    'ReleaseEvent': _release,
+    'StatusEvent': identity,
     'TeamAddEvent': _team,
-    'WatchEvent': lambda x: x,
+    'WatchEvent': identity,
 }
