@@ -8,20 +8,20 @@ This module contains the main GitHub session object.
 """
 from __future__ import unicode_literals
 
-from github3.auths import Authorization
-from github3.decorators import (requires_auth, requires_basic_auth,
-                                requires_app_credentials)
-from github3.events import Event
-from github3.gists import Gist
-from github3.issues import Issue, issue_params
-from github3.models import GitHubCore
-from github3.orgs import Organization, Team
-from github3.repos import Repository
-from github3.search import (CodeSearchResult, IssueSearchResult,
-                            RepositorySearchResult, UserSearchResult)
-from github3.structs import SearchIterator
-from github3.users import User, Key
-from github3.notifications import Thread
+from .auths import Authorization
+from .decorators import (requires_auth, requires_basic_auth,
+                         requires_app_credentials)
+from .events import Event
+from .gists import Gist
+from .issues import Issue, issue_params
+from .models import GitHubCore
+from .orgs import Membership, Organization, Team
+from .repos import Repository
+from .search import (CodeSearchResult, IssueSearchResult,
+                     RepositorySearchResult, UserSearchResult)
+from .structs import SearchIterator
+from .users import User, Key
+from .notifications import Thread
 from uritemplate import URITemplate
 
 
@@ -931,6 +931,14 @@ class GitHub(GitHubCore):
                 return req.content
         return ''  # (No coverage)
 
+    @requires_auth
+    def membership_in(self, organization):
+        """Retrieve the user's membership in the specified organization."""
+        url = self._build_url('user', 'memberships', 'orgs',
+                              str(organization))
+        json = self._json(self._get(url), 200)
+        return Membership(json, self)
+
     def meta(self):
         """Returns a dictionary with arrays of addresses in CIDR format
         specifying theaddresses that the incoming service hooks will originate
@@ -962,6 +970,22 @@ class GitHub(GitHubCore):
         json = self._json(self._get(url), 200)
         return Organization(json, self) if json else None
 
+    @requires_auth
+    def organization_memberships(self, state=None, number=-1, etag=None):
+        """List organizations of which the user is a current or pending member.
+
+        :param str state: (option), state of the membership, i.e., active,
+            pending
+        :returns: iterator of :class:`Membership <github3.orgs.Membership>`
+        """
+        params = None
+        url = self._build_url('user', 'memberships', 'orgs')
+        if state is not None and state.lower() in ('active', 'pending'):
+            params = {'state': state.lower()}
+        return self._iter(int(number), url, Membership,
+                          params=params,
+                          etag=etag)
+
     @requires_auth
     def pubsubhubbub(self, mode, topic, callback, secret=''):
         """Create/update a pubsubhubbub hook.
@@ -1459,10 +1483,14 @@ class GitHubEnterprise(GitHub):
 
     There is no need to provide the end of the url (e.g., /api/v3/), that will
     be taken care of by us.
+
+    If you have a self signed SSL for your local github enterprise you can
+    override the validation by passing `verify=False`.
     """
-    def __init__(self, url, login='', password='', token=''):
+    def __init__(self, url, login='', password='', token='', verify=True):
         super(GitHubEnterprise, self).__init__(login, password, token)
         self._session.base_url = url.rstrip('/') + '/api/v3'
+        self._session.verify = verify
 
     def _repr(self):
         return '<GitHub Enterprise [0.url]>'.format(self)
