@@ -11,30 +11,30 @@ from __future__ import unicode_literals
 
 from json import dumps
 from base64 import b64encode
-from github3.decorators import requires_auth
-from github3.events import Event
-from github3.git import Blob, Commit, Reference, Tag, Tree
-from github3.issues import issue_params, Issue
-from github3.issues.event import IssueEvent
-from github3.issues.label import Label
-from github3.issues.milestone import Milestone
-from github3.models import GitHubCore
-from github3.notifications import Subscription, Thread
-from github3.pulls import PullRequest
-from github3.repos.branch import Branch
-from github3.repos.comment import RepoComment
-from github3.repos.commit import RepoCommit
-from github3.repos.comparison import Comparison
-from github3.repos.contents import Contents, validate_commmitter
-from github3.repos.deployment import Deployment
-from github3.repos.hook import Hook
-from github3.repos.pages import PagesBuild, PagesInfo
-from github3.repos.status import Status
-from github3.repos.stats import ContributorStats
-from github3.repos.release import Release, Asset
-from github3.repos.tag import RepoTag
-from github3.users import User, Key
-from github3.utils import stream_response_to_file, timestamp_parameter
+from ..decorators import requires_auth
+from ..events import Event
+from ..git import Blob, Commit, Reference, Tag, Tree
+from ..issues import issue_params, Issue
+from ..issues.event import IssueEvent
+from ..issues.label import Label
+from ..issues.milestone import Milestone
+from ..models import GitHubCore
+from ..notifications import Subscription, Thread
+from ..pulls import PullRequest
+from .branch import Branch
+from .comment import RepoComment
+from .commit import RepoCommit
+from .comparison import Comparison
+from .contents import Contents, validate_commmitter
+from .deployment import Deployment
+from .hook import Hook
+from .pages import PagesBuild, PagesInfo
+from .status import Status
+from .stats import ContributorStats
+from .release import Release, Asset
+from .tag import RepoTag
+from ..users import User, Key
+from ..utils import stream_response_to_file, timestamp_parameter
 from uritemplate import URITemplate
 
 
@@ -71,7 +71,9 @@ class Repository(GitHubCore):
         self.forks = repo.get('forks', 0)
 
         #: The number of forks of this repository.
-        self.fork_count = repo.get('fork_count')
+        self.forks_count = repo.get('forks_count')
+        # For backward compatibility
+        self.fork_count = self.forks_count
 
         #: Is this repository a fork?
         self.fork = repo.get('fork')
@@ -504,7 +506,7 @@ class Repository(GitHubCore):
 
     @requires_auth
     def create_deployment(self, ref, force=False, payload='',
-                          auto_merge=False, description=''):
+                          auto_merge=False, description='', environment=None):
         """Create a deployment.
 
         :param str ref: (required), The ref to deploy. This can be a branch,
@@ -516,13 +518,17 @@ class Repository(GitHubCore):
         :param bool auto_merge: Optional parameter to merge the default branch
             into the requested deployment branch if necessary. Default: False
         :param str description: Optional short description. Default: ""
+        :param str environment: Optional name for the target deployment
+            environment (e.g., production, staging, qa). Default: "production"
         :returns: :class:`Deployment <github3.repos.deployment.Deployment>`
         """
         json = None
         if ref:
             url = self._build_url('deployments', base_url=self._api)
             data = {'ref': ref, 'force': force, 'payload': payload,
-                    'auto_merge': auto_merge, 'description': description}
+                    'auto_merge': auto_merge, 'description': description,
+                    'environment': environment}
+            self._remove_none(data)
             headers = Deployment.CUSTOM_HEADERS
             json = self._json(self._post(url, data=data, headers=headers),
                               201)
@@ -699,12 +705,11 @@ class Repository(GitHubCore):
 
     @requires_auth
     def create_pull(self, title, base, head, body=None):
-        """Create a pull request using commits from ``head`` and comparing
-        against ``base``.
+        """Create a pull request of ``head`` onto ``base`` branch in this repo.
 
         :param str title: (required)
-        :param str base: (required), e.g., 'username:branch', or a sha
-        :param str head: (required), e.g., 'master', or a sha
+        :param str base: (required), e.g., 'master'
+        :param str head: (required), e.g., 'username:branch'
         :param str body: (optional), markdown formatted description
         :returns: :class:`PullRequest <github3.pulls.PullRequest>` if
             successful, else None
@@ -718,8 +723,8 @@ class Repository(GitHubCore):
         """Create a pull request from issue #``issue``.
 
         :param int issue: (required), issue number
-        :param str base: (required), e.g., 'username:branch', or a sha
-        :param str head: (required), e.g., 'master', or a sha
+        :param str base: (required), e.g., 'master'
+        :param str head: (required), e.g., 'username:branch'
         :returns: :class:`PullRequest <github3.pulls.PullRequest>` if
             successful, else None
         """
@@ -1173,8 +1178,8 @@ class Repository(GitHubCore):
             listed
         :param str author: (optional), GitHub login, real name, or email to
             filter commits by (using commit author)
-        :param int number: (optional), number of comments to return. Default:
-            -1 returns all comments
+        :param int number: (optional), number of commits to return. Default:
+            -1 returns all commits
         :param str etag: (optional), ETag from a previous request to the same
             endpoint
         :param since: (optional), Only commits after this date will
@@ -1606,7 +1611,7 @@ class Repository(GitHubCore):
             endpoint
         :returns: generator of :class:`Team <github3.orgs.Team>`\ s
         """
-        from github3.orgs import Team
+        from ..orgs import Team
         url = self._build_url('teams', base_url=self._api)
         return self._iter(int(number), url, Team, etag=etag)
 
