@@ -1,6 +1,6 @@
 import github3
 import datetime
-from tests.utils import BaseCase, load, expect
+from tests.utils import BaseCase, load
 
 
 class TestThread(BaseCase):
@@ -11,36 +11,36 @@ class TestThread(BaseCase):
 
     def test_equality(self):
         t = github3.notifications.Thread(load('notification'))
-        expect(self.thread) == t
-        t.id = 1
-        expect(self.thread) != t
+        assert self.thread == t
+        t._uniq = 1
+        assert self.thread != t
 
     def test_last_read_at(self):
         json = self.thread.to_json().copy()
         json['last_read_at'] = '2013-12-31T23:59:59Z'
         t = github3.notifications.Thread(json)
-        expect(t.last_read_at).isinstance(datetime.datetime)
+        assert isinstance(t.last_read_at, datetime.datetime)
 
     def test_repr(self):
-        expect(repr(self.thread)) == '<Thread [{0}]>'.format(
+        assert repr(self.thread) == '<Thread [{0}]>'.format(
             self.thread.subject.get('title'))
 
     def test_delete_subscription(self):
         self.response('', 204)
         self.delete(self.api + '/subscription')
 
-        expect(self.thread.delete_subscription()).is_True()
+        assert self.thread.delete_subscription()
         self.mock_assertions()
 
     def test_is_unread(self):
-        expect(self.thread.is_unread()) == self.thread.unread
+        assert self.thread.is_unread() == self.thread.unread
 
     def test_mark(self):
         self.response('', 205)
         self.patch(self.api)
         self.conf = {}
 
-        expect(self.thread.mark()).is_True()
+        assert self.thread.mark()
         self.mock_assertions()
 
     def test_set_subscription(self):
@@ -48,16 +48,16 @@ class TestThread(BaseCase):
         self.put(self.api + '/subscription')
         self.conf = {'data': {'subscribed': True, 'ignored': False}}
 
-        expect(self.thread.set_subscription(True, False)).isinstance(
-            github3.notifications.Subscription)
+        assert isinstance(self.thread.set_subscription(True, False),
+                          github3.notifications.Subscription)
         self.mock_assertions()
 
     def test_subscription(self):
         self.response('subscription')
         self.get(self.api + '/subscription')
 
-        expect(self.thread.subscription()).isinstance(
-            github3.notifications.Subscription)
+        assert isinstance(self.thread.subscription(),
+                          github3.notifications.Subscription)
         self.mock_assertions()
 
 
@@ -70,29 +70,26 @@ class TestSubscription(BaseCase):
                     "subscription")
 
     def test_repr(self):
-        expect(repr(self.subscription)) == '<Subscription [{0}]>'.format(True)
-        # The above formatting is for pypy. Otherwise you get "<Subscription 
-        # [1]>" == "<Subscription [True]>" so we let the interpreter do the 
-        # string interpolation for us.
+        assert isinstance(repr(self.subscription), str)
 
     def test_delete(self):
         self.response('', 204)
         self.delete(self.api)
 
-        expect(self.subscription.delete()).is_True()
+        assert self.subscription.delete()
         self.mock_assertions()
 
     def test_is_ignored(self):
-        expect(self.subscription.is_ignored()) == self.subscription.ignored
+        assert self.subscription.is_ignored() == self.subscription.ignored
 
     def test_is_subscription(self):
         subbed = self.subscription.is_subscribed()
-        expect(subbed) == self.subscription.subscribed
+        assert subbed == self.subscription.subscribed
 
     def test_set(self):
         self.response('subscription')
         self.put(self.api)
         self.conf = {'data': {'subscribed': True, 'ignored': False}}
 
-        expect(self.subscription.set(True, False)).is_None()
+        assert self.subscription.set(True, False) is None
         self.mock_assertions()
